==> senior_design_tokens-0.3.2.tar.gz: example/lib/pages/typographies.example.dart <==
import 'package:flutter/material.dart';

// ignore: depend_on_referenced_packages
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class TypographyExample extends StatelessWidget {
  const TypographyExample({Key? key}) : super(key: key);

  Widget _buildText(TextStyle style) {
    return Text(
      'Exemplo de texto',
      style: style,
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Typography',
      child: Padding(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        child: SingleChildScrollView(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'h1',
                child: _buildText(SeniorTypography.h1(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'h2',
                child: _buildText(SeniorTypography.h2(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'h3',
                child: _buildText(SeniorTypography.h3(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'h4',
                child: _buildText(SeniorTypography.h4(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'CTA',
                child: _buildText(SeniorTypography.cta(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'title',
                child: _buildText(SeniorTypography.title(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'text',
                child: _buildText(SeniorTypography.text(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'body',
                child: _buildText(SeniorTypography.body(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'body-semi-bold',
                child: _buildText(SeniorTypography.bodySemiBold(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'small',
                child: _buildText(SeniorTypography.small(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'small-bold',
                child: _buildText(SeniorTypography.smallBold(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'helper',
                child: _buildText(SeniorTypography.helper(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'tiny',
                child: _buildText(SeniorTypography.tiny(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'title-card-regular',
                child: _buildText(SeniorTypography.titleCardRegular(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
              Panel(
                title: 'title-card-bold',
                child: _buildText(SeniorTypography.titleCardBold(
                  color: SeniorColors.primaryColor[700],
                )),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_tokens-1.2.0.tar.gz: example/lib/pages/typographies.example.dart <==
import 'package:flutter/material.dart';

// ignore: depend_on_referenced_packages
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class TypographyExample extends StatelessWidget {
  const TypographyExample({Key? key}) : super(key: key);

  Widget _buildText(TextStyle style) {
    return Text(
      'Exemplo de texto',
      style: style,
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Typography',
      child: Padding(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        child: SingleChildScrollView(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'h1',
                child: _buildText(SeniorTypography.h1(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'h2',
                child: _buildText(SeniorTypography.h2(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'h3',
                child: _buildText(SeniorTypography.h3(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'h4',
                child: _buildText(SeniorTypography.h4(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'CTA',
                child: _buildText(SeniorTypography.cta(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'title',
                child: _buildText(SeniorTypography.title(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'text',
                child: _buildText(SeniorTypography.text(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'body',
                child: _buildText(SeniorTypography.body(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'body-semi-bold',
                child: _buildText(SeniorTypography.bodySemiBold(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'small',
                child: _buildText(SeniorTypography.small(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'small-bold',
                child: _buildText(SeniorTypography.smallBold(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'helper',
                child: _buildText(SeniorTypography.helper(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'tiny',
                child: _buildText(SeniorTypography.tiny(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'title-card-regular',
                child: _buildText(SeniorTypography.titleCardRegular(
                  color: SeniorColors.primaryColor700,
                )),
              ),
              Panel(
                title: 'title-card-bold',
                child: _buildText(SeniorTypography.titleCardBold(
                  color: SeniorColors.primaryColor700,
                )),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
